=========================
 Invenio-Celery v1.0.0a4
=========================

Invenio-Celery v1.0.0a4 was released on February 28, 2016.

About
-----

Integration layer between Celery and Invenio.

*This is an experimental developer preview release.*

Installation
------------

   $ pip install invenio-celery==1.0.0a4

Documentation
-------------

   http://pythonhosted.org/invenio-celery/

Happy hacking and thanks for flying Invenio-Celery.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-celery
|   URL: http://invenio-software.org
